==> ubuntu_localizations-0.1.3.tar.gz: lib/src/l10n/ubuntu_localizations_fr.dart <==
import 'ubuntu_localizations.dart';

/// The translations for French (`fr`).
class UbuntuLocalizationsFr extends UbuntuLocalizations {
  UbuntuLocalizationsFr([String locale = 'fr']) : super(locale);

  @override
  String get countryCode => 'FR';

  @override
  String get languageName => 'Français';

  @override
  String get backAction => 'Retour';

  @override
  String get continueAction => 'Continuer';

  @override
  String get strongPassword => 'Mot de passe sûr';

  @override
  String get fairPassword => 'Mot de passe acceptable';

  @override
  String get goodPassword => 'Mot de passe sûr';

  @override
  String get weakPassword => 'Mot de passe trop faible';

  @override
  String get altKey => 'Alt';

  @override
  String get controlKey => 'Contrôle';

  @override
  String get metaKey => 'Méta';

  @override
  String get shiftKey => 'Majuscule';

  @override
  String get aboutLabel => 'À propos';

  @override
  String get addLabel => 'Ajouter';

  @override
  String get allLabel => 'All';

  @override
  String get applyLabel => 'Appliquer';

  @override
  String get ascendingLabel => 'Ascendant';

  @override
  String get backLabel => 'Back';

  @override
  String get boldLabel => 'Gras';

  @override
  String get bottomLabel => 'Bottom';

  @override
  String get cancelLabel => 'Annuler';

  @override
  String get centerLabel => 'Center';

  @override
  String get clearLabel => 'Clear';

  @override
  String get closeLabel => 'Fermer';

  @override
  String get colorLabel => 'Couleur';

  @override
  String get connectLabel => 'Se connecter';

  @override
  String get continueLabel => 'Continuer';

  @override
  String get copyLabel => 'Copier';

  @override
  String get createLabel => 'Créer';

  @override
  String get cutLabel => 'Couper';

  @override
  String get decreaseLabel => 'Decrease';

  @override
  String get deleteLabel => 'Supprimer';

  @override
  String get descendingLabel => 'Descendant';

  @override
  String get discardLabel => 'Discard';

  @override
  String get disconnectLabel => 'Déconnecter';

  @override
  String get doneLabel => 'Done';

  @override
  String get downloadLabel => 'Télécharger';

  @override
  String get editLabel => 'Modifier';

  @override
  String get enterLabel => 'Entrer';

  @override
  String get errorLabel => 'Erreur';

  @override
  String get executeLabel => 'Exécuter';

  @override
  String get exitLabel => 'Quitter';

  @override
  String get fileLabel => 'Fichier';

  @override
  String get fillLabel => 'Remplir';

  @override
  String get findLabel => 'Trouver';

  @override
  String get firstLabel => 'Premier';

  @override
  String get fontLabel => 'Police';

  @override
  String get forwardLabel => 'Forward';

  @override
  String get fullscreenLabel => 'Plein écran';

  @override
  String get goBackLabel => 'Revenir en arrière';

  @override
  String get helpLabel => 'Aide';

  @override
  String get homeLabel => 'Accueil';

  @override
  String get importLabel => 'Importer';

  @override
  String get increaseLabel => 'Augmenter';

  @override
  String get indexLabel => 'Index';

  @override
  String get informationLabel => 'Information';

  @override
  String get insertLabel => 'Insérer';

  @override
  String get italicLabel => 'Italique';

  @override
  String get landscapeLabel => 'Paysage';

  @override
  String get lastLabel => 'Dernier';

  @override
  String get leaveLabel => 'Leave';

  @override
  String get leftLabel => 'Gauche';

  @override
  String get mediaLabel => 'Média';

  @override
  String get networkLabel => 'Réseau';

  @override
  String get newLabel => 'Nouveau';

  @override
  String get nextLabel => 'Suivant';

  @override
  String get noLabel => 'Non';

  @override
  String get noneLabel => 'Aucune';

  @override
  String get normalLabel => 'Normal';

  @override
  String get okLabel => 'OK';

  @override
  String get openLabel => 'Ouvrir';

  @override
  String get pasteLabel => 'Coller';

  @override
  String get pauseLabel => 'Pause';

  @override
  String get playLabel => 'Jouer';

  @override
  String get portraitLabel => 'Portrait';

  @override
  String get preferencesLabel => 'Préférences';

  @override
  String get previousLabel => 'Précédent';

  @override
  String get printLabel => 'Imprimer';

  @override
  String get printPreviewLabel => 'Aperçu avant impression';

  @override
  String get propertiesLabel => 'Propriétés';

  @override
  String get questionLabel => 'Question';

  @override
  String get quitLabel => 'Quitter';

  @override
  String get recordLabel => 'Enregistrer';

  @override
  String get redoLabel => 'Rétablir';

  @override
  String get refreshLabel => 'Rafraîchir';

  @override
  String get removeLabel => 'Supprimer';

  @override
  String get renameLabel => 'Renommer';

  @override
  String get resetLabel => 'Réinitialiser';

  @override
  String get restoreLabel => 'Restaurer';

  @override
  String get retryLabel => 'Réessayer';

  @override
  String get revertLabel => 'Rétablir';

  @override
  String get rewindLabel => 'Rembobiner';

  @override
  String get rightLabel => 'Droite';

  @override
  String get saveAsLabel => 'Enregistrer sous';

  @override
  String get saveLabel => 'Enregistrer';

  @override
  String get searchLabel => 'Chercher';

  @override
  String get selectAllLabel => 'Tout sélectionner';

  @override
  String get selectLabel => 'Sélectionner';

  @override
  String get sendLabel => 'Envoyer';

  @override
  String get skipLabel => 'Ignorer';

  @override
  String get sortLabel => 'Trier';

  @override
  String get stopLabel => 'Arrêter';

  @override
  String get strikeThroughLabel => 'Barré';

  @override
  String get submitLabel => 'Soumettre';

  @override
  String get topLabel => 'Top';

  @override
  String get undoLabel => 'Annuler';

  @override
  String get updateLabel => 'Mettre à jour';

  @override
  String get upLabel => 'Up';

  @override
  String get viewLabel => 'Voir';

  @override
  String get warningLabel => 'Avertissement';

  @override
  String get windowLabel => 'Fenêtre';

  @override
  String get yesLabel => 'Oui';

  @override
  String get zoomInLabel => 'Zoomer';

  @override
  String get zoomOutLabel => 'Dézoomer';
}

==> ubuntu_localizations-0.2.0.tar.gz: lib/src/l10n/ubuntu_localizations_fr.dart <==
import 'ubuntu_localizations.dart';

/// The translations for French (`fr`).
class UbuntuLocalizationsFr extends UbuntuLocalizations {
  UbuntuLocalizationsFr([String locale = 'fr']) : super(locale);

  @override
  String get countryCode => 'FR';

  @override
  String get languageName => 'Français';

  @override
  String get backAction => 'Retour';

  @override
  String get continueAction => 'Continuer';

  @override
  String get strongPassword => 'Mot de passe sûr';

  @override
  String get fairPassword => 'Mot de passe acceptable';

  @override
  String get goodPassword => 'Mot de passe sûr';

  @override
  String get weakPassword => 'Mot de passe trop faible';

  @override
  String get altKey => 'Alt';

  @override
  String get controlKey => 'Contrôle';

  @override
  String get metaKey => 'Méta';

  @override
  String get shiftKey => 'Majuscule';

  @override
  String get aboutLabel => 'À propos';

  @override
  String get addLabel => 'Ajouter';

  @override
  String get allLabel => 'Tous';

  @override
  String get applyLabel => 'Appliquer';

  @override
  String get ascendingLabel => 'Ascendant';

  @override
  String get backLabel => 'Retour';

  @override
  String get boldLabel => 'Gras';

  @override
  String get bottomLabel => 'Bottom';

  @override
  String get cancelLabel => 'Annuler';

  @override
  String get centerLabel => 'Center';

  @override
  String get clearLabel => 'Clear';

  @override
  String get closeLabel => 'Fermer';

  @override
  String get colorLabel => 'Couleur';

  @override
  String get connectLabel => 'Se connecter';

  @override
  String get continueLabel => 'Continuer';

  @override
  String get copyLabel => 'Copier';

  @override
  String get createLabel => 'Créer';

  @override
  String get cutLabel => 'Couper';

  @override
  String get decreaseLabel => 'Diminuer';

  @override
  String get deleteLabel => 'Supprimer';

  @override
  String get descendingLabel => 'Descendant';

  @override
  String get discardLabel => 'Abandonner';

  @override
  String get disconnectLabel => 'Déconnecter';

  @override
  String get doneLabel => 'Terminé';

  @override
  String get downloadLabel => 'Télécharger';

  @override
  String get editLabel => 'Modifier';

  @override
  String get enterLabel => 'Entrer';

  @override
  String get errorLabel => 'Erreur';

  @override
  String get executeLabel => 'Exécuter';

  @override
  String get exitLabel => 'Quitter';

  @override
  String get fileLabel => 'Fichier';

  @override
  String get fillLabel => 'Remplir';

  @override
  String get findLabel => 'Trouver';

  @override
  String get firstLabel => 'Premier';

  @override
  String get fontLabel => 'Police';

  @override
  String get forwardLabel => 'Forward';

  @override
  String get fullscreenLabel => 'Plein écran';

  @override
  String get goBackLabel => 'Revenir en arrière';

  @override
  String get helpLabel => 'Aide';

  @override
  String get homeLabel => 'Accueil';

  @override
  String get importLabel => 'Importer';

  @override
  String get increaseLabel => 'Augmenter';

  @override
  String get indexLabel => 'Index';

  @override
  String get informationLabel => 'Information';

  @override
  String get insertLabel => 'Insérer';

  @override
  String get italicLabel => 'Italique';

  @override
  String get landscapeLabel => 'Paysage';

  @override
  String get lastLabel => 'Dernier';

  @override
  String get leaveLabel => 'Quitter';

  @override
  String get leftLabel => 'Gauche';

  @override
  String get mediaLabel => 'Média';

  @override
  String get networkLabel => 'Réseau';

  @override
  String get newLabel => 'Nouveau';

  @override
  String get nextLabel => 'Suivant';

  @override
  String get noLabel => 'Non';

  @override
  String get noneLabel => 'Aucune';

  @override
  String get normalLabel => 'Normal';

  @override
  String get okLabel => 'OK';

  @override
  String get openLabel => 'Ouvrir';

  @override
  String get pasteLabel => 'Coller';

  @override
  String get pauseLabel => 'Pause';

  @override
  String get playLabel => 'Jouer';

  @override
  String get portraitLabel => 'Portrait';

  @override
  String get preferencesLabel => 'Préférences';

  @override
  String get previousLabel => 'Précédent';

  @override
  String get printLabel => 'Imprimer';

  @override
  String get printPreviewLabel => 'Aperçu avant impression';

  @override
  String get propertiesLabel => 'Propriétés';

  @override
  String get questionLabel => 'Question';

  @override
  String get quitLabel => 'Quitter';

  @override
  String get recordLabel => 'Enregistrer';

  @override
  String get redoLabel => 'Rétablir';

  @override
  String get refreshLabel => 'Rafraîchir';

  @override
  String get removeLabel => 'Supprimer';

  @override
  String get renameLabel => 'Renommer';

  @override
  String get resetLabel => 'Réinitialiser';

  @override
  String get restoreLabel => 'Restaurer';

  @override
  String get retryLabel => 'Réessayer';

  @override
  String get revertLabel => 'Rétablir';

  @override
  String get rewindLabel => 'Rembobiner';

  @override
  String get rightLabel => 'Droite';

  @override
  String get saveAsLabel => 'Enregistrer sous';

  @override
  String get saveLabel => 'Enregistrer';

  @override
  String get searchLabel => 'Chercher';

  @override
  String get selectAllLabel => 'Tout sélectionner';

  @override
  String get selectLabel => 'Sélectionner';

  @override
  String get sendLabel => 'Envoyer';

  @override
  String get skipLabel => 'Ignorer';

  @override
  String get sortLabel => 'Trier';

  @override
  String get stopLabel => 'Arrêter';

  @override
  String get strikeThroughLabel => 'Barré';

  @override
  String get submitLabel => 'Soumettre';

  @override
  String get topLabel => 'Top';

  @override
  String get undoLabel => 'Annuler';

  @override
  String get updateLabel => 'Mettre à jour';

  @override
  String get upLabel => 'Up';

  @override
  String get viewLabel => 'Voir';

  @override
  String get warningLabel => 'Avertissement';

  @override
  String get windowLabel => 'Fenêtre';

  @override
  String get yesLabel => 'Oui';

  @override
  String get zoomInLabel => 'Zoomer';

  @override
  String get zoomOutLabel => 'Dézoomer';
}
